@@ -1,4 +1,4 @@
-from os import name, path
+from os import name, path, system as os_system
 import cloudsync as cs
 import tempfile as tf
 from .cc_debug import cc_print
@@ -6,9 +6,30 @@ from .config import make_auth
 import pandas as pd
 import json
 from . import vars
+import sys
+import pkg_resources
+
+# Override the creds_changed function to suppress the warning
+def creds_changed(x):  # pylint: disable=unused-argument
+    pass
+
+# Override function cs.registry.discover_providers
+def discover_providers():
+    """Loop through imported modules, and autoregister providers, including plugins"""
+    for m in sys.modules:
+        mod = sys.modules[m]
+        if hasattr(mod, "__cloudsync__")  and ("cloudsync" in mod.__name__):
+            print(mod.__name__)
+            if (mod.__cloudsync__.name not in cs.registry.providers):   # type: ignore
+                register_provider(mod.__cloudsync__)                    # type: ignore  
+    for entry_point in pkg_resources.iter_entry_points('cloudsync.providers'):
+        cs.register_provider(entry_point.resolve())
 
 def connect():
+    # Override cs.registry.discover_providers > causing bug with TensorFlow
+    cs.registry.discover_providers = discover_providers
     oauth_config = cs.command.utils.generic_oauth_config('onedrive')
+    oauth_config.creds_changed = creds_changed
     if vars.token is None:
         if vars.creds_path == "":
             make_auth()
@@ -58,8 +79,7 @@ def download_file(filename, namespace=None, output=None, cached=True, force_dl=F
         This may be useful instead of re-downloading many times the same file, for speed of execution.
         The temp dir may be periodically emptied by your system daemons (systemd).
         '''
-        if cached and (not force_dl):
-            print("[DEBUG] caching file...")
+        if cached:
             fname = vars.tempdir + filename.split("/")[-1] # Split filename
             tmp = open(fname, 'wb+')    # Open the file in binary mode ('b') > tmp must be _io.BufferedRandom
         else:
@@ -69,7 +89,12 @@ def download_file(filename, namespace=None, output=None, cached=True, force_dl=F
         cc_print("Downloading to {} ...".format(fname), 1)
     else:
         tmp = open(output, 'wb+')
-    vars.provider.download_path(filename, tmp)
+    try:
+        vars.provider.download_path(filename, tmp)
+    except:
+        tmp.close()
+        os_system("rm {}".format(tmp))
+        return None
     tmp.seek(0) # Go back to first line
     return tmp
 
